@@ -39,7 +39,7 @@ wayback url format.
 """
 
 import re
-
+import urllib
 
 #=================================================================
 class BaseWbUrl(object):
@@ -149,6 +149,14 @@ class WbUrl(BaseWbUrl):
         self.timestamp = timestamp
         self.type = self.REPLAY
 
+
+    def deprefix_url(self, prefix):
+        prefix = urllib.quote_plus(prefix)
+        rex_query = '=' + re.escape(prefix) + '([0-9])*([\w]{2}_)?/?'
+        new_url = re.sub(rex_query, '=', self.url)
+        self.url = new_url
+        return self.url
+
     # Str Representation
     # ====================
     def to_str(self, **overrides):
