@@ -1,23 +1,44 @@
+/*
+Copyright(c) 2013-2014 Ilya Kreymer. Released under the GNU General Public License.
+
+This file is part of pywb, https://github.com/ikreymer/pywb
+
+    pywb is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    pywb is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with pywb.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 var LIVE_COOKIE_REGEX = /pywb.timestamp=([\d]{1,14})/;
 
+var TS_REGEX = /\/([\d]{1,14})\//;
+
 var curr_state = {};
 
 
 function make_outer_url(url, ts)
 {
     if (ts) {
-        return wbinfo.prefix + ts + "/" + url;
+        return wbinfo.prefix + ts + "tf_/" + url;
     } else {
-        return wbinfo.prefix + url;
+        return wbinfo.prefix + "tf_/" + url;
     }
 }
 
 function make_inner_url(url, ts)
 {
     if (ts) {
-        return wbinfo.prefix + ts + "mp_/" + url;
+        return wbinfo.prefix + ts + "/" + url;
     } else {
-        return wbinfo.prefix + "mp_/" + url;
+        return wbinfo.prefix + "/" + url;
     }
 }
 
@@ -39,7 +60,7 @@ function push_state(url, timestamp, capture_str, is_live) {
     state.capture_str = capture_str;
     state.is_live = is_live;
     
-    window.history.replaceState(state, "", state.outer_url);
+    window.history.replaceState(state, "", state.inner_url);
 
     set_state(state);
 }
@@ -52,16 +73,12 @@ function pop_state(state) {
 
 function extract_ts(url)
 {
-    var inx = url.indexOf("mp_");
-    if (inx < 0) {
+    var result = value.match(TS_REGEX);
+    if (!result) {
         return "";
     }
-    url = url.substring(0, inx);
-    inx = url.lastIndexOf("/");
-    if (inx <= 0) {
-        return "";
-    }
-    return url.substring(inx + 1);
+
+    return result[1];
 }
 
 function extract_replay_url(url) {
@@ -84,9 +101,9 @@ function set_state(state) {
     var label = document.getElementById("_wb_label");
     if (label) {
         if (state.is_live) {
-            label.innerHTML = _wb_js.labels.LIVE_MSG;
+            label.innerHTML = _wb_js.banner_labels.LIVE_MSG;
         } else {
-            label.innerHTML = _wb_js.labels.REPLAY_MSG;
+            label.innerHTML = _wb_js.banner_labels.REPLAY_MSG;
         }
     }
 
@@ -147,3 +164,8 @@ function update_wb_url(url, ts, is_live) {
 
     push_state(url, ts, capture_str, is_live);
 }
+
+// Load Banner
+if (_wb_js) {
+    _wb_js.load();
+}
