@@ -32,12 +32,11 @@ class ArchiveIterator(object):
 
         self.member_info = None
 
-    def iter_records(self):
+    def iter_records(self, block_size=16384):
         """ iterate over each record
         """
 
         decomp_type = 'gzip'
-        block_size = 16384
 
         self.reader = DecompressingBufferedReader(self.fh,
                                                   block_size=block_size)
@@ -168,6 +167,8 @@ class ArchiveIndexEntry(object):
         self.status = status_headers.get_statuscode()
         if not self.status:
             self.status = '-'
+        if self.status == '204' and 'Error' in status_headers.statusline:
+            self.status = '-'
 
     def set_rec_info(self, offset, length, digest):
         self.offset = str(offset)
@@ -202,8 +203,9 @@ class ArchiveIndexEntry(object):
 def create_record_iter(arcv_iter, options):
     append_post = options.get('append_post')
     include_all = options.get('include_all')
+    block_size = options.get('block_size', 16384)
 
-    for record in arcv_iter.iter_records():
+    for record in arcv_iter.iter_records(block_size):
         entry = None
 
         if not include_all and (record.status_headers.get_statuscode() == '-'):
@@ -314,11 +316,11 @@ def parse_warc_record(record):
                            get_header('Content-Type'),
                            def_mime)
 
-    # status
-    if record.rec_type in ('request', 'revisit'):
-        entry.status = '-'
-    else:
+    # status -- only for response records (by convention):
+    if record.rec_type == 'response':
         entry.extract_status(record.status_headers)
+    else:
+        entry.status = '-'
 
     # digest
     entry.digest = record.rec_headers.get_header('WARC-Payload-Digest')
